@@ -45,15 +45,15 @@
 #' grouped by the specified \code{distance} is produced. If the specified \code{distance}
 #' has not yet been calculated an error is returned.\cr\cr
 #' If \code{map = FALSE} and the input is a \code{CRTanalysis} object a plot of the
-#' estimated contamination function is generated. The fitted contamination function is plotted
+#' estimated spillover function is generated. The fitted spillover function is plotted
 #' as a continuous blue line against the measure
 #' the surround or of the distance to the nearest discordant location. Using the same axes, data summaries are plotted for
 #' ten categories of distance from the boundary. Both the
 #' average of the outcome and confidence intervals are plotted.
 #' \itemize{
 #' \item For analyses with logit link function the outcome is plotted as a proportion. \cr
-#' \item For analyses with log or cloglog link function the outcome is plotted on a scale of the Williams mean
-#' (mean of exp(log(x + 1))) - 1)\cr
+#' \item For analyses with log or cloglog link function the data are plotted on a scale of the Williams mean
+#' (mean of exp(log(x + 1))) - 1) rescaled so that the median matches the fitted curve at the midpoint.\cr
 #' }
 #' If \code{map = TRUE} a thematic map corresponding to the value of \code{fill} is generated.
 #' \itemize{
@@ -67,10 +67,10 @@
 #' \itemize{
 #' \item If the trial has not been randomised or if \code{showBuffer = FALSE} no buffer is displayed
 #' \item If \code{buffer_width} takes a positive value then buffers of this width are
-#' displayed irrespective of any pre-specified or contamination limits.
-#' \item If the input is a \code{'CRTanalysis'} and contamination limits have been estimated by
+#' displayed irrespective of any pre-specified or spillover limits.
+#' \item If the input is a \code{'CRTanalysis'} and spillover limits have been estimated by
 #' an \code{'LME4'} or \code{'INLA'} model then these limits are used to define the displayed buffer.
-#' \item If \code{buffer_width} is not specified and no contamination limits are available, then any
+#' \item If \code{buffer_width} is not specified and no spillover limits are available, then any
 #' pre-specified buffer (e.g. one generated by \code{specify_buffer()}) is displayed.
 #' }
 #' A message is output indicating which of these possibilities applies.
@@ -92,7 +92,7 @@
 #' #show arms
 #' plotCRT(example, map = TRUE,
 #' fill = 'arms', maskbuffer=0.2, legend.position=c(0.8,0.8))
-#' #contamination plot
+#' #spillover plot
 #' analysis <- CRTanalysis(example)
 #'  plotCRT(analysis, map = FALSE)
 #' }
@@ -120,24 +120,37 @@ plotCRT <- function(object, map = FALSE, distance = "nearestDiscord", fill = "ar
         if (isa(object, what = 'CRTanalysis')) {
             # if the object is the output from analysisCRT
             analysis <- object
-            if (is.null(analysis$contamination$FittedCurve))
+            if (is.null(analysis$spillover$FittedCurve))
                 stop("*** No fitted curve available ***")
-            d <- average <- upper <- lower <- contaminationFunction <- NULL
-            interval <- analysis$contamination$contamination_limits
+            d <- average <- upper <- lower <- spilloverFunction <- NULL
+            interval <- analysis$spillover$spillover_limits
             range <- max(analysis$trial[[distance]]) - min(analysis$trial[[distance]])
             data <- group_data(analysis = analysis, grouping = "quintiles")
-            FittedCurve <- analysis$contamination$FittedCurve
+            FittedCurve <- analysis$spillover$FittedCurve
+            fitted_median <- median(c(FittedCurve$control_curve,FittedCurve$intervention_curve),na.rm = TRUE)
+            data_median <- median(data$average)
+            if (analysis$options$link %in% c('log', 'cloglog')) {
+                scale_factor <- fitted_median/data_median
+                data_scaled <- data.frame(
+                                    d = data$d,
+                                    arm = data$arm,
+                                    average = data$average * scale_factor,
+                                    lower = data$lower * scale_factor,
+                                    upper = data$upper * scale_factor)
+            } else {
+                data_scaled <- data
+            }
             g <- ggplot2::ggplot() + ggplot2::theme_bw()
             g <- g + ggplot2::geom_line(data = FittedCurve[!is.na(FittedCurve$control_curve), ],
                             ggplot2::aes(x = d, y = control_curve), linewidth = 2, colour = "#b2df8a")
             g <- g + ggplot2::geom_line(data = FittedCurve[!is.na(FittedCurve$intervention_curve), ],
                             ggplot2::aes(x = d, y = intervention_curve), linewidth = 2, colour = "#0072A7")
-            g <- g + ggplot2::geom_point(data = data, ggplot2::aes(x = d, y = average,
+            g <- g + ggplot2::geom_point(data = data_scaled, ggplot2::aes(x = d, y = average,
                                         shape=factor(arm)), size = 2)
             g <- g + ggplot2::scale_shape_manual(name = "Arms", values = c(0, 16),
                                                  labels = c("Control", "Intervention"))
             g <- g + ggplot2::theme(legend.position = legend.position)
-            g <- g + ggplot2::geom_errorbar(data = data, mapping = ggplot2::aes(x = d, ymin = upper,
+            g <- g + ggplot2::geom_errorbar(data = data_scaled, mapping = ggplot2::aes(x = d, ymin = upper,
                                         ymax = lower), linewidth = 0.5, width = range/50)
             if (identical(analysis$options$distance, "nearestDiscord")) {
                 g <- g + ggplot2::geom_vline(xintercept = 0, linewidth = 1, linetype = "dashed")
@@ -179,7 +192,7 @@ plotCRT <- function(object, map = FALSE, distance = "nearestDiscord", fill = "ar
         showArms <- identical(fill, "arms")
         if (isa(object, what = 'CRTanalysis')) {
             analysis <- object
-            contamination_limits <- analysis$contamination$contamination_limits
+            spillover_limits <- analysis$spillover$spillover_limits
              if(!(fill %in% c("arms", "clusters"))){
                 # raster map derived from inla analysis
                 x <- y <- prediction <- nearestDiscord <- NULL
@@ -243,7 +256,7 @@ plotCRT <- function(object, map = FALSE, distance = "nearestDiscord", fill = "ar
             cpalette <- c("white")
 
         if (showBuffer) trial <- modifyBuffer(trial = trial, buffer_width = buffer_width,
-                                              contamination_limits = contamination_limits)
+                                              spillover_limits = spillover_limits)
         if (is.null(trial$buffer)) showBuffer <- FALSE
 
         sf_objects <- sf_objects(trial = trial, maskbuffer = maskbuffer)
@@ -386,7 +399,7 @@ return(sf_objects)
 #' \tabular{ll}{
 #' \code{'cluster'}\tab cluster assignments \cr
 #' \code{'arms'}\tab arm assignments \cr
-#' \code{'buffer'}\tab buffer zone or contamination zone\cr
+#' \code{'buffer'}\tab buffer zone or spillover zone\cr
 #' \code{'mask'}\tab mask for areas that are distant from habitations \cr
 #' }
 #' @param buffer_width width of buffer between discordant locations (km)
@@ -415,10 +428,10 @@ return(sf_objects)
 #'     }
 #' @export
 CRTwrite <- function(object, dsn, feature = 'clusters', buffer_width, maskbuffer = 0.2, ...){
-    contamination_limits <- NULL
+    spillover_limits <- NULL
     if (isa(object, what = 'CRTanalysis')) {
-        contamination_limits <- ifelse(is.null(object$contamination$contamination_limits), NULL,
-                                       object$contamination$contamination_limits)
+        spillover_limits <- ifelse(is.null(object$spillover$spillover_limits), NULL,
+                                       object$spillover$spillover_limits)
         object <- object$trial
     }
     object <- CRTsp(object)
@@ -426,7 +439,7 @@ CRTwrite <- function(object, dsn, feature = 'clusters', buffer_width, maskbuffer
     trial <- object$trial
     if (identical(feature,"buffer")) {
         trial <- modifyBuffer(trial = trial, buffer_width = buffer_width,
-                  contamination_limits = contamination_limits)
+                  spillover_limits = spillover_limits)
         if (is.null(trial$buffer)) stop("No buffer available for export")
     }
     sf_objects <- sf_objects(trial = trial, maskbuffer = maskbuffer,
@@ -434,16 +447,16 @@ CRTwrite <- function(object, dsn, feature = 'clusters', buffer_width, maskbuffer
     sf::st_write(sf_objects[[feature]], dsn = dsn, ...)
 }
 
-modifyBuffer <- function(trial, buffer_width, contamination_limits){
+modifyBuffer <- function(trial, buffer_width, spillover_limits){
     if (!is.null(trial$nearestDiscord)){
         if (!is.null(buffer_width)){
             trial$buffer <-  ifelse(dplyr::between(trial$nearestDiscord,
                                -buffer_width, buffer_width), TRUE, FALSE)
     message("Buffer includes locations within ", buffer_width*1000, "m of the opposing arm")
-        } else if(!is.null(contamination_limits)) {
+        } else if(!is.null(spillover_limits)) {
             trial$buffer <-  ifelse(dplyr::between(trial$nearestDiscord,
-            contamination_limits[1], contamination_limits[2]), TRUE, FALSE)
-            message("Buffer corresponds to estimated contamination zone")
+            spillover_limits[1], spillover_limits[2]), TRUE, FALSE)
+            message("Buffer corresponds to estimated spillover zone")
         } else {
             if (!is.null(trial$buffer)) {
                 message("Buffer corresponds pre-specified buffer zone")
